Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(374)

Unified Diff: components/autofill/core/browser/autofill_client.h

Issue 2789843004: [Payments] Upload card UI now has a CVC prompt (Closed)
Patch Set: Attempt to fix memory leak Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/autofill/core/browser/autofill_client.h
diff --git a/components/autofill/core/browser/autofill_client.h b/components/autofill/core/browser/autofill_client.h
index a10c3b302684c78690546db6f8b465235c3e553b..3f03cd4fe249a9bff808191c5f576769d05906e9 100644
--- a/components/autofill/core/browser/autofill_client.h
+++ b/components/autofill/core/browser/autofill_client.h
@@ -49,6 +49,7 @@ class CardUnmaskDelegate;
class CreditCard;
class FormStructure;
class PersonalDataManager;
+class SaveCardBubbleController;
struct Suggestion;
// A client interface that needs to be supplied to the Autofill component by the
@@ -110,9 +111,13 @@ class AutofillClient : public RiskDataLoader {
// Gets the RapporServiceImpl associated with the client (for metrics).
virtual rappor::RapporServiceImpl* GetRapporServiceImpl() = 0;
- // Gets the UKM service assiciated with this client (for metrics).
+ // Gets the UKM service associated with this client (for metrics).
virtual ukm::UkmService* GetUkmService() = 0;
+ // Gets the SaveCardBubbleController instance associated with the client.
+ // May return nullptr if the save card bubble has not been shown yet.
+ virtual SaveCardBubbleController* GetSaveCardBubbleController() = 0;
+
// Causes the Autofill settings UI to be shown.
virtual void ShowAutofillSettings() = 0;
@@ -129,10 +134,12 @@ class AutofillClient : public RiskDataLoader {
const base::Closure& callback) = 0;
// Runs |callback| if the |card| should be uploaded to Payments. Displays the
// contents of |legal_message| to the user.
Evan Stade 2017/04/12 15:21:31 nit: single space after . (there is not consistenc
Jared Saul 2017/04/12 22:49:21 Done.
+ // if |should_cvc_be_requested| is true.
virtual void ConfirmSaveCreditCardToCloud(
const CreditCard& card,
std::unique_ptr<base::DictionaryValue> legal_message,
+ bool should_cvc_be_requested,
const base::Closure& callback) = 0;
// Will show an infobar to get user consent for Credit Card assistive filling.
@@ -129,10 +134,12 @@ class AutofillClient : public RiskDataLoader {
const base::Closure& callback) = 0;
// Runs |callback| if the |card| should be uploaded to Payments. Displays the
- // contents of |legal_message| to the user.
+ // contents of |legal_message| to the user. Display a CVC field in the bubble
Evan Stade 2017/04/12 15:21:31 nit: single space after . (there is not consistenc
Jared Saul 2017/04/12 22:49:21 Done.

Powered by Google App Engine
This is Rietveld 408576698